summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-11-17 21:14:34 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-11-17 21:39:58 -0600
commit36251d3f766c49fd0da43ef40dea7d9b5486392f (patch)
treef1139f694e1cce79198b22266eaf784653b49dc6 /png.h
parentd92c1fcd550e1e8120c7941b3f968455e7457f5b (diff)
downloadlibpng-36251d3f766c49fd0da43ef40dea7d9b5486392f.tar.gz
[libpng15] Bump version to libpng-1.5.7beta05
Diffstat (limited to 'png.h')
-rw-r--r--png.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/png.h b/png.h
index c96a4c11b..3086b9640 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.7beta04 - November 18, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.7beta04 - November 18, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -163,7 +163,7 @@
* 1.5.6beta01-07 15 10506 15.so.15.6[.0]
* 1.5.6rc01-03 15 10506 15.so.15.6[.0]
* 1.5.6 15 10506 15.so.15.6[.0]
- * 1.5.7beta01-04 15 10507 15.so.15.7[.0]
+ * 1.5.7beta01-05 15 10507 15.so.15.7[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -195,7 +195,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 18, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -313,7 +313,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.7beta04 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -371,9 +371,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.7beta04"
+#define PNG_LIBPNG_VER_STRING "1.5.7beta05"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.7beta04 - November 18, 2011\n"
+ " libpng version 1.5.7beta05 - November 18, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -534,7 +534,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_7beta04;
+typedef char* png_libpng_version_1_5_7beta05;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.7beta04 - November 18, 2011
+ * libpng version 1.5.7beta05 - November 18, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.7beta04 - November 18, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.7beta05 - November 18, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -195,7 +195,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 18, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta05, November 18, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -313,7 +313,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.7beta04 are Y2K compliant. It is my belief that
+ * upward through 1.5.7beta05 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*